"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var ts_smart_logger_1 = require("ts-smart-logger");
var util_1 = require("../../util");
var di_1 = require("../../di");
var connector_action_builder_1 = require("./connector-action.builder");
var stack_interface_1 = require("../../store/stack/stack.interface");
var universal_connector_factory_1 = require("./universal-connector.factory");
var logger = ts_smart_logger_1.LoggerFactory.makeLogger('universal-connector.decorator');
/**
 * @stable - 23.04.2018
 * @param {IBasicConnectorEntity<TStoreEntity>} config
 * @returns {(target: IContainerClassEntity) => void}
 */
exports.basicConnector = function (config) {
    return function (target) {
        var finalTarget = target;
        var sectionName = util_1.ifNotNilThanValue(target.defaultProps, function (defaultProps) { return defaultProps.sectionName; });
        if (sectionName) {
            di_1.getDynamicSections().set(sectionName, config);
            finalTarget = /** @class */ (function (_super) {
                __extends(class_1, _super);
                /**
                 * @stable [09.10.2019]
                 * @param {IUniversalContainerProps} props
                 */
                function class_1(props) {
                    var _this = _super.call(this, props) || this;
                    util_1.patchRenderMethod(_this);
                    logger.debug("[$basicConnector][constructor] Section: " + sectionName);
                    return _this;
                }
                /**
                 * @stable [02.12.2019]
                 */
                class_1.prototype.componentWillUnmount = function () {
                    var store = di_1.getStore();
                    store.dispatch({ type: stack_interface_1.STACK_POP_ACTION_TYPE, data: sectionName });
                    store.dispatch({ type: connector_action_builder_1.ConnectorActionBuilder.buildDestroyActionType(sectionName) });
                    logger.debug("[$basicConnector][componentWillUnmount] Section: " + sectionName);
                    if (util_1.isFn(_super.prototype.componentWillUnmount)) {
                        _super.prototype.componentWillUnmount.call(this);
                    }
                };
                /**
                 * @stable [11.09.2019]
                 */
                class_1.prototype.componentDidMount = function () {
                    var store = di_1.getStore();
                    store.dispatch({ type: stack_interface_1.STACK_PUSH_ACTION_TYPE, data: sectionName });
                    store.dispatch({ type: connector_action_builder_1.ConnectorActionBuilder.buildInitActionType(sectionName) });
                    logger.debug("[$basicConnector][componentDidMount] Section: " + sectionName);
                    if (util_1.isFn(_super.prototype.componentDidMount)) {
                        _super.prototype.componentDidMount.call(this);
                    }
                };
                return class_1;
            }(target));
        }
        else {
            logger.warn("[$basicConnector] The sectionName is not defined for " + (target.name ||
                target) + ". The init and destroy actions are disabled.");
        }
        di_1.getDynamicRoutes().set(universal_connector_factory_1.universalConnectorFactory.apply(void 0, [finalTarget].concat(config.mappers)), config);
    };
};
/**
 * @stable - 23.04.2018
 * @param {IConnectorEntity<TStoreEntity extends IUniversalStoreEntity, TAccessConfig>} config
 * @returns {(target: IContainerClassEntity) => void}
 */
exports.connector = function (config) { return exports.basicConnector(config); };
//# sourceMappingURL=universal-connector.decorator.js.map