"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var ts_smart_logger_1 = require("ts-smart-logger");
var util_1 = require("../../../util");
var textfield_1 = require("../../field/textfield");
var menu_1 = require("../../menu");
var definition_1 = require("../../../definition");
var BaseSelect = /** @class */ (function (_super) {
    __extends(BaseSelect, _super);
    /**
     * @stable [30.11.2019]
     * @param {TProps} props
     */
    function BaseSelect(props) {
        var _this = _super.call(this, props) || this;
        _this.menuRef = React.createRef();
        _this.onClose = _this.onClose.bind(_this);
        _this.onFilterChange = _this.onFilterChange.bind(_this);
        _this.onSelect = _this.onSelect.bind(_this);
        _this.openMenu = _this.openMenu.bind(_this);
        if (util_1.isExpandActionRendered(_this.props)) {
            _this.defaultActions = [
                { type: props.icon || definition_1.FieldActionTypesEnum.DROP_DOWN, onClick: _this.openMenu }
            ].concat(_this.defaultActions);
        }
        return _this;
    }
    /**
     * @stable [30.11.2019]
     * @param {Readonly<TProps extends IBaseSelectProps>} prevProps
     * @param {Readonly<TState extends IBaseSelectState>} prevState
     */
    BaseSelect.prototype.componentDidUpdate = function (prevProps, prevState) {
        var _this = this;
        _super.prototype.componentDidUpdate.call(this, prevProps, prevState);
        var props = this.props;
        if (this.state.needToBeOpened) {
            util_1.ifNotNilThanValue(props.options, function () {
                _this.setState({ needToBeOpened: false }, function () {
                    _this.showMenu();
                    if (util_1.isFn(props.onLoadDictionary)) {
                        props.onLoadDictionary(_this.filteredOptions);
                    }
                });
            });
        }
        var newValue = props.value;
        if (R.isNil(newValue) && !R.equals(newValue, prevProps.value)) {
            var $$cachedValue = this.state.$$cachedValue;
            if (!R.isNil($$cachedValue) && !R.equals($$cachedValue.value, newValue)) {
                // Need to reset the previous cached display value if the value has been cleared or replaced
                this.setState({ $$cachedValue: null });
            }
        }
    };
    BaseSelect.prototype.onKeyBackspace = function (event) {
        _super.prototype.onKeyBackspace.call(this, event);
        this.clearValue();
    };
    BaseSelect.prototype.onKeyEnter = function (event) {
        _super.prototype.onKeyEnter.call(this, event);
        this.openMenu(event);
    };
    BaseSelect.prototype.onKeyEscape = function (event) {
        _super.prototype.onKeyEscape.call(this, event);
        if (this.menu.isOpen()) {
            this.hideMenu();
        }
    };
    /**
     * @stable [30.11.2019]
     */
    BaseSelect.prototype.clearValue = function () {
        _super.prototype.clearValue.call(this);
        this.setState({ $$cachedValue: null });
    };
    /**
     * @stable [30.11.2019]
     * @param {IBaseEvent} event
     */
    BaseSelect.prototype.openMenu = function (event) {
        if (this.menu.isOpen() || this.state.needToBeOpened) {
            return;
        }
        util_1.cancelEvent(event);
        var _a = this.props, onEmptyDictionary = _a.onEmptyDictionary, bindDictionary = _a.bindDictionary, options = _a.options, forceReload = _a.forceReload;
        var areOptionsEmpty = R.isNil(options);
        if (forceReload || areOptionsEmpty) {
            if (util_1.isFn(onEmptyDictionary)) {
                onEmptyDictionary(bindDictionary);
                this.setState({ needToBeOpened: true }); // After callback invoking (!)
            }
            else if (!areOptionsEmpty) {
                this.showMenu();
            }
        }
        else {
            this.showMenu();
        }
    };
    Object.defineProperty(BaseSelect.prototype, "inProgress", {
        /**
         * @stable [30.11.2019]
         * @returns {boolean}
         */
        get: function () {
            return util_1.inProgress(this.props) || this.state.needToBeOpened === true;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [25.02.2019]
     * @param {IBaseEvent} event
     */
    BaseSelect.prototype.onClick = function (event) {
        _super.prototype.onClick.call(this, event);
        this.openMenu(event);
    };
    /**
     * @stable [01.06.2018]
     * @returns {JSX.Element}
     */
    BaseSelect.prototype.getInputAttachmentElement = function () {
        var props = this.props;
        return (React.createElement(menu_1.Menu, __assign({ ref: this.menuRef, width: this.menuWidth, options: this.filteredOptions, onSelect: this.onSelect, onFilterChange: this.onFilterChange, onClose: this.onClose }, props.menuConfiguration)));
    };
    Object.defineProperty(BaseSelect.prototype, "filteredOptions", {
        /**
         * @stable [30.11.2019]
         * @returns {ISelectOptionEntity[]}
         */
        get: function () {
            return this.options;
        },
        enumerable: true,
        configurable: true
    });
    BaseSelect.prototype.getFieldClassName = function () {
        return util_1.joinClassName(_super.prototype.getFieldClassName.call(this), 'rac-base-select');
    };
    /**
     * @stable [29.06.2018]
     * @returns {AnyT}
     */
    BaseSelect.prototype.getEmptyValue = function () {
        var props = this.props;
        return util_1.isDef(props.emptyValue) ? props.emptyValue : this.settings.entityEmptyId;
    };
    /**
     * @stable [30.11.2019]
     * @param {ISelectOptionEntity} option
     */
    BaseSelect.prototype.onSelect = function (option) {
        var _this = this;
        this.setState({
            $$cachedValue: {
                value: option.value,
                label: String(option.label || option.value),
            },
        }, function () {
            _this.onChangeManually(option.value);
            var onSelect = _this.props.onSelect;
            if (util_1.isFn(onSelect)) {
                onSelect(option);
            }
        });
    };
    /**
     * @stable [10.09.2019]
     */
    BaseSelect.prototype.onClose = function () {
        var props = this.props;
        if (util_1.isFn(props.onClose)) {
            props.onClose();
        }
    };
    /**
     * @stable [12.02.2019]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    BaseSelect.prototype.getDecoratedValue = function (value) {
        var $$cachedValue = this.state.$$cachedValue;
        if (!R.isNil($$cachedValue)) {
            return _super.prototype.getDecoratedValue.call(this, $$cachedValue.label, false);
        }
        var selectedItem = R.find(function (option) { return option.value === value; }, this.options);
        return R.isNil(selectedItem)
            ? _super.prototype.getDecoratedValue.call(this, value)
            : (_super.prototype.getDecoratedValue.call(this, R.isNil(selectedItem.label)
                ? selectedItem.value
                : this.t(selectedItem.label), false));
    };
    Object.defineProperty(BaseSelect.prototype, "options", {
        /**
         * @stable [20.08.2018]
         * @returns {ISelectOptionEntity[]}
         */
        get: function () {
            return util_1.calc(this.props.options) || [];
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [30.11.2019]
     */
    BaseSelect.prototype.showMenu = function () {
        if (R.isEmpty(this.filteredOptions)) {
            BaseSelect.logger.debug('[$BaseSelect][showMenu] The options are empty. The menu does not show.');
        }
        else {
            this.menu.show();
        }
    };
    /**
     * @stable [20.08.2018]
     */
    BaseSelect.prototype.hideMenu = function () {
        this.menu.hide();
    };
    BaseSelect.prototype.onFilterChange = function (query) {
        var props = this.props;
        var onFilterChange = props.onFilterChange;
        var onDictionaryFilterChange = props.onDictionaryFilterChange;
        if (util_1.isFn(onFilterChange)) {
            onFilterChange(query);
        }
        if (util_1.isFn(onDictionaryFilterChange)) {
            onDictionaryFilterChange(props.bindDictionary, { payload: { query: query } });
        }
    };
    Object.defineProperty(BaseSelect.prototype, "menuWidth", {
        /**
         * @stable [23.11.2019]
         * @returns {number}
         */
        get: function () {
            return util_1.getWidth(this.getSelf());
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "menu", {
        /**
         * @stable [30.11.2019]
         * @returns {IMenu}
         */
        get: function () {
            return this.menuRef.current;
        },
        enumerable: true,
        configurable: true
    });
    BaseSelect.logger = ts_smart_logger_1.LoggerFactory.makeLogger('BaseSelect');
    return BaseSelect;
}(textfield_1.BaseTextField));
exports.BaseSelect = BaseSelect;
//# sourceMappingURL=base-select.component.js.map