import { AnyAction } from 'redux';
import { IEffectsAction } from 'redux-effects-promise';
import { AnyT, IKeyValue } from '../../definitions.interface';
import { FieldChangeEntityT } from '../../definition';
export declare class FormActionBuilder {
    /**
     * @stable [21.01.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildDestroyActionType(section: string): string;
    /**
     * @stable [26.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildClearActionType(section: string): string;
    /**
     * @stable [02.10.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildChangeActionType(section: string): string;
    /**
     * @stable [24.02.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildResetActionType(section: string): string;
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildValidActionType(section: string): string;
    /**
     * @stable [14.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildActiveValueActionType(section: string): string;
    /**
     * @stable [02.09.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildDeactivatedValueActionType(section: string): string;
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitActionType(section: string): string;
    /**
     * @stable [17.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildProgressActionType(section: string): string;
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitDoneActionType(section: string): string;
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitFinishedActionType(section: string): string;
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitErrorActionType(section: string): string;
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildSubmitDoneAction(section: string): IEffectsAction;
    /**
     * @stable [24.02.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildResetAction(section: string): IEffectsAction;
    /**
     * @stable [17.04.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildProgressAction(section: string): IEffectsAction;
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @param {boolean} valid
     * @returns {IEffectsAction}
     */
    static buildValidAction(section: string, valid: boolean): IEffectsAction;
    static buildSubmitFinishedAction(section: string): IEffectsAction;
    /**
     * @stable [21.01.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildDestroyAction(section: string): IEffectsAction;
    static buildChangeAction(section: string, data: FieldChangeEntityT): IEffectsAction;
    /**
     * @stable [26.08.2018]
     * @param {string} section
     * @param {string} fieldName
     * @returns {IEffectsAction}
     */
    static buildClearSimpleAction(section: string, fieldName: string): IEffectsAction;
    /**
     * @stable [18.04.2019]
     * @param {string} section
     * @param {string} fieldName
     * @returns {IEffectsAction}
     */
    static buildClearAction(section: string, fieldName: string): IEffectsAction;
    /**
     * @stable - 10.04.2018
     * @param {string} section
     * @param {IKeyValue} changes
     * @returns {IEffectsAction}
     */
    static buildChangesAction<TData extends IKeyValue = IKeyValue>(section: string, changes: TData): IEffectsAction;
    /**
     * @stable [09.10.2019]
     * @param {string} section
     * @param {TData} changes
     * @returns {AnyAction}
     */
    static buildChangesPlainAction<TData extends IKeyValue = IKeyValue>(section: string, changes: TData): AnyAction;
    /**
     * @stable [09.10.2019]
     * @param {string} section
     * @param {string} name
     * @param {AnyT} value
     * @returns {AnyAction}
     */
    static buildChangePlainAction(section: string, name: string, value?: AnyT): AnyAction;
    /**
     * @stable [11.09.2019]
     * @param {string} section
     * @returns {AnyAction}
     */
    static buildResetPlainAction(section: string): AnyAction;
    /**
     * @stable [26.08.2018]
     * @param {IKeyValue} changes
     * @returns {FieldChangeEntityT}
     */
    private static buildChangesPayload;
}
