"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var Promise = require("bluebird");
var React = require("react");
var R = require("ramda");
var base_1 = require("../../base");
var menu_1 = require("../../menu");
var util_1 = require("../../../util");
var google_maps_interface_1 = require("./google-maps.interface");
var flex_1 = require("../../layout/flex");
var GoogleMaps = /** @class */ (function (_super) {
    __extends(GoogleMaps, _super);
    /**
     * @stable [31.07.2018]
     * @param {IGoogleMapsProps} props
     */
    function GoogleMaps(props) {
        var _this = _super.call(this, props) || this;
        _this.markers = new Map();
        _this.markersDragListeners = new Map();
        _this.onMapClick = _this.onMapClick.bind(_this);
        _this.onMapDbClick = _this.onMapDbClick.bind(_this);
        _this.onMenuSelect = _this.onMenuSelect.bind(_this);
        _this.openMenu = _this.openMenu.bind(_this);
        _this.initGoogleMapsObjects = _this.initGoogleMapsObjects.bind(_this);
        _this.addHeatMapLayer = _this.addHeatMapLayer.bind(_this);
        if (_this.haveMenuOptions) {
            _this.openMenuTask = new util_1.DelayedTask(_this.openMenu, 200);
        }
        return _this;
    }
    /**
     * @stable [31.07.2018]
     */
    GoogleMaps.prototype.componentDidMount = function () {
        var _this = this;
        _super.prototype.componentDidMount.call(this);
        // We cannot cancel the original promise, because of it is shared
        this.googleMapsScriptTask = new Promise(function (resolve, reject) { return util_1.getGoogleMapsScript(_this.settings.googleMaps.libraries).then(resolve, reject); }).then(this.initGoogleMapsObjects);
    };
    /**
     * @stable [31.07.2018]
     */
    GoogleMaps.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        if (util_1.isDef(this.openMenuTask)) {
            this.openMenuTask.stop();
        }
        this.cancelGoogleMapsScriptTaskIfPending();
        this.markersDragListeners.forEach(function (dragEndEventListener) { return dragEndEventListener.remove(); });
        if (util_1.isDef(this.clickEventListener)) {
            this.clickEventListener.remove();
        }
        if (util_1.isDef(this.dbClickEventListener)) {
            this.dbClickEventListener.remove();
        }
        this.map = null;
        this.heatMapLayer = null;
        this.openMenuTask = null;
        this.googleMapsScriptTask = null;
    };
    /**
     * @stable [31.07.2018]
     * @returns {JSX.Element}
     */
    GoogleMaps.prototype.render = function () {
        var _this = this;
        var props = this.props;
        return (React.createElement(flex_1.FlexLayout, { className: util_1.toClassName('rac-google-maps', props.className) },
            React.createElement("div", { ref: this.selfRef, className: 'rac-google-maps-map rac-flex-full' }),
            util_1.orNull(this.haveMenuOptions, function () { return (React.createElement(menu_1.Menu, { ref: 'menu', xPosition: function () { return _this.x + _this.getSelf().offsetLeft; }, yPosition: function () { return _this.y + _this.getSelf().offsetTop; }, options: props.menuOptions, onSelect: _this.onMenuSelect })); })));
    };
    /**
     * @stable [31.07.2018]
     * @param {google.maps.MarkerOptions} cfg
     * @param {string} name
     * @returns {google.maps.Marker}
     */
    GoogleMaps.prototype.addMarker = function (cfg, name) {
        var _this = this;
        var config = __assign({ anchorPoint: new google.maps.Point(0, -29), position: null }, cfg, { map: this.map });
        var markerId = name || util_1.uuid();
        var marker = new google.maps.Marker(config);
        this.markers.set(markerId, marker);
        if (config.draggable) {
            this.markersDragListeners.set(markerId, google.maps.event.addListener(marker, 'dragend', function () { return _this.onMarkerDragEnd(markerId, marker); }));
        }
        return marker;
    };
    /**
     * @stable [23.02.2019]
     * @param {IGoogleMapsMarkerConfigEntity} cfg
     */
    GoogleMaps.prototype.setMarkerState = function (cfg) {
        var marker = cfg.marker, visible = cfg.visible, refreshMap = cfg.refreshMap, _a = cfg.lat, lat = _a === void 0 ? this.mapsSettings.lat : _a, _b = cfg.lng, lng = _b === void 0 ? this.mapsSettings.lng : _b, _c = cfg.zoom, zoom = _c === void 0 ? this.mapsSettings.zoom : _c;
        var markerAsObject = util_1.isString(marker) ? this.markers.get(marker) : marker;
        markerAsObject.setPosition({ lat: lat, lng: lng });
        markerAsObject.setVisible(visible);
        if (refreshMap) {
            this.refreshMap({ lat: lat, lng: lng }, zoom);
        }
    };
    /**
     * @stable [04.03.2019]
     * @param {IGoogleMapsHeatMapLayerConfigEntity} cfg
     */
    GoogleMaps.prototype.addHeatMapLayer = function (cfg) {
        var points = cfg.points;
        var isArrayOfPointsNotEmpty = util_1.isArrayNotEmpty(points);
        if (isArrayOfPointsNotEmpty) {
            this.heatMapLayer = new google.maps.visualization.HeatmapLayer({
                map: this.map,
                data: points.map(function (point) { return new google.maps.LatLng(point.lat, point.lng); }),
            });
        }
        if (cfg.refreshMap) {
            this.refreshMap(isArrayOfPointsNotEmpty ? points[0] : this.mapsSettings, util_1.nvl(cfg.zoom, this.mapsSettings.zoom));
        }
    };
    /**
     * @stable [31.07.2018]
     * @param {string} markerId
     * @param {google.maps.Marker} marker
     */
    GoogleMaps.prototype.onMarkerDragEnd = function (markerId, marker) {
        var position = marker.getPosition();
        var lat = position.lat();
        var lng = position.lng();
        var props = this.props;
        if (props.onChangePlace) {
            props.onChangePlace({ name: markerId, item: marker, lat: lat, lng: lng });
        }
    };
    /**
     * @stable [31.07.2018]
     * @param {IMenuItemEntity} item
     */
    GoogleMaps.prototype.onMenuSelect = function (item) {
        var props = this.props;
        if (props.onSelect) {
            props.onSelect({ item: item, lat: this.lat, lng: this.lng });
        }
    };
    /**
     * @stable [03.03.2019]
     * @param {IGoogleMapsClickPayloadEntity} event
     */
    GoogleMaps.prototype.onMapClick = function (event) {
        var props = this.props;
        if (event.pixel) {
            var x = event.pixel.x;
            var y = event.pixel.y;
            var lat = event.latLng.lat();
            var lng = event.latLng.lng();
            if (util_1.isDef(this.openMenuTask)) {
                this.openMenuTask.start({ x: x, y: y, lat: lat, lng: lng });
            }
        }
        if (util_1.isFn(props.onClick)) {
            props.onClick(event);
        }
    };
    /**
     * @stable [03.03.2019]
     * @param {IGoogleMapsClickPayloadEntity} event
     */
    GoogleMaps.prototype.onMapDbClick = function (event) {
        if (this.haveMenuOptions) {
            this.openMenuTask.stop();
        }
    };
    /**
     * @stable [31.07.2018]
     */
    GoogleMaps.prototype.cancelGoogleMapsScriptTaskIfPending = function () {
        this.cancelTaskIfPending(this.googleMapsScriptTask);
    };
    /**
     * @stable [31.07.2018]
     */
    GoogleMaps.prototype.cancelTaskIfPending = function (promise) {
        if (promise && promise.isPending()) {
            promise.cancel();
        }
    };
    /**
     * @stable [31.07.2018]
     * @param {{x: number; y: number; lat: number; lng: number}} nextState
     */
    GoogleMaps.prototype.openMenu = function (nextState) {
        Object.assign(this, nextState); // We need to sync the internal state with a starting task state
        this.menu.show();
    };
    /**
     * @stable [31.07.2018]
     */
    GoogleMaps.prototype.initGoogleMapsObjects = function () {
        var props = this.props;
        var _a = props.options, options = _a === void 0 ? {} : _a;
        // google.maps.MapTypeId enum is loaded as a lazy resource (within a lazy loaded script)
        var mapTypes = new Map();
        mapTypes.set(google_maps_interface_1.GoogleMapsMapTypeEnum.SATELLITE, google.maps.MapTypeId.SATELLITE);
        mapTypes.set(google_maps_interface_1.GoogleMapsMapTypeEnum.HYBRID, google.maps.MapTypeId.HYBRID);
        mapTypes.set(google_maps_interface_1.GoogleMapsMapTypeEnum.TERRAIN, google.maps.MapTypeId.TERRAIN);
        this.map = new google.maps.Map(this.getSelf(), __assign({}, options, { mapTypeId: mapTypes.get(options.mapTypeId) || google.maps.MapTypeId.ROADMAP }));
        this.clickEventListener = google.maps.event.addListener(this.map, 'click', this.onMapClick);
        this.dbClickEventListener = google.maps.event.addListener(this.map, 'dblclick', this.onMapDbClick);
        if (props.onInit) {
            props.onInit(this.map);
        }
    };
    /**
     * @stable [04.03.2019]
     * @param {ILatLngEntity} latLng
     * @param {number} zoom
     */
    GoogleMaps.prototype.refreshMap = function (latLng, zoom) {
        this.map.setCenter({ lat: latLng.lat, lng: latLng.lng });
        this.map.setZoom(zoom);
    };
    Object.defineProperty(GoogleMaps.prototype, "menu", {
        /**
         * @stable [31.07.2018]
         * @returns {IMenu}
         */
        get: function () {
            return this.refs.menu;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GoogleMaps.prototype, "haveMenuOptions", {
        /**
         * @stable [26.10.2018]
         * @returns {boolean}
         */
        get: function () {
            return !R.isNil(this.props.menuOptions);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GoogleMaps.prototype, "mapsSettings", {
        /**
         * @stable [04.03.2019]
         * @returns {IGoogleMapsSettings}
         */
        get: function () {
            return this.settings.googleMaps;
        },
        enumerable: true,
        configurable: true
    });
    return GoogleMaps;
}(base_1.BaseComponent));
exports.GoogleMaps = GoogleMaps;
//# sourceMappingURL=google-maps.component.js.map