"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var redux_effects_promise_1 = require("redux-effects-promise");
var util_1 = require("../../util");
var list_interface_1 = require("./list.interface");
var ListActionBuilder = /** @class */ (function () {
    function ListActionBuilder() {
    }
    /**
     * @stable [13.11.2019]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildSortingDirectionChangeActionType = function (section) {
        return section + "." + list_interface_1.LIST_SORTING_DIRECTION_CHANGE_ACTION_TYPE;
    };
    ListActionBuilder.buildChangeActionType = function (section) {
        return section + "." + list_interface_1.LIST_CHANGE_ACTION_TYPE;
    };
    ListActionBuilder.buildFirstPageActionType = function (section) {
        return section + "." + list_interface_1.LIST_FIRST_PAGE_ACTION_TYPE;
    };
    ListActionBuilder.buildLastPageActionType = function (section) {
        return section + "." + list_interface_1.LIST_LAST_PAGE_ACTION_TYPE;
    };
    ListActionBuilder.buildPreviousPageActionType = function (section) {
        return section + "." + list_interface_1.LIST_PREVIOUS_PAGE_ACTION_TYPE;
    };
    ListActionBuilder.buildNextPageActionType = function (section) {
        return section + "." + list_interface_1.LIST_NEXT_PAGE_ACTION_TYPE;
    };
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildLoadActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_LOAD_ACTION_TYPE;
    };
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildCancelLoadActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_CANCEL_LOAD_ACTION_TYPE;
    };
    /**
     * @stable [03.06.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildLazyLoadActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_LAZY_LOAD_ACTION_TYPE;
    };
    /**
     * @stable [03.06.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildLazyLoadDoneActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_LAZY_LOAD_DONE_ACTION_TYPE;
    };
    ListActionBuilder.buildUnTouchActionType = function (section) {
        return section + "." + list_interface_1.LIST_UN_TOUCH_ACTION_TYPE;
    };
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildLoadDoneActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_LOAD_DONE_ACTION_TYPE;
    };
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildLoadErrorActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_LOAD_ERROR_ACTION_TYPE;
    };
    /**
     * @stable [04.06.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildLazyLoadErrorActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_LAZY_LOAD_ERROR_ACTION_TYPE;
    };
    /**
     * @stable [07.12.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildSelectActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_SELECT_ACTION_TYPE;
    };
    /**
     * @stable [07.12.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildSelectErrorActionType = function (section) {
        return redux_effects_promise_1.EffectsActionBuilder.buildErrorActionType(this.buildSelectActionType(section));
    };
    ListActionBuilder.buildInsertActionType = function (section) {
        return section + "." + list_interface_1.LIST_INSERT_ACTION_TYPE;
    };
    /**
     * @stable [17.05.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildRemoveActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_REMOVE_ACTION_TYPE;
    };
    ListActionBuilder.buildUpdateActionType = function (section) {
        return section + "." + list_interface_1.LIST_UPDATE_ACTION_TYPE;
    };
    /**
     * @stable [07.12.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildCreateActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_CREATE_ACTION_TYPE;
    };
    /**
     * @stable [26.10.2019]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildDeselectActionType = function (section) {
        return section + "." + list_interface_1.LIST_DESELECT_ACTION_TYPE;
    };
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildDestroyActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_DESTROY_ACTION_TYPE;
    };
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildResetActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + list_interface_1.LIST_RESET_ACTION_TYPE;
    };
    /**
     * @stable [19.10.2019]
     * @param {string} section
     * @param {ISelectedWrapperEntity<TEntity extends IEntity>} selectedWrapper
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildLazyLoadDoneAction = function (section, selectedWrapper) {
        return redux_effects_promise_1.EffectsAction.create(this.buildLazyLoadDoneActionType(section), util_1.applySection(section, selectedWrapper));
    };
    /**
     * @stable [15.03.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildCreateAction = function (section) {
        var plainAction = this.buildCreatePlainAction(section);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [03.06.2018]
     * @param {string} section
     * @param {ISelectedWrapperEntity} payload
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildLazyLoadAction = function (section, payload) {
        return redux_effects_promise_1.EffectsAction.create(this.buildLazyLoadActionType(section), util_1.applySection(section, payload));
    };
    ListActionBuilder.buildDeselectAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildDeselectActionType(section), util_1.applySection(section));
    };
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildDestroyAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildDestroyActionType(section), util_1.applySection(section));
    };
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildResetAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildResetActionType(section), util_1.applySection(section));
    };
    /**
     * @stable [17.05.2018]
     * @param {string} section
     * @param {IRemovedEntityWrapper} data
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildRemoveAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildRemoveActionType(section), util_1.applySection(section, data));
    };
    ListActionBuilder.buildUpdateAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildUpdateActionType(section), util_1.applySection(section, data));
    };
    /**
     * @stable [20.10.2019]
     * @param {string} section
     * @param {EntityIdT} id
     * @param {TChanges} changes
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildMergeItemAction = function (section, id, changes) {
        return this.buildMergeAction(section, { payload: { id: id, changes: changes } });
    };
    ListActionBuilder.buildLoadAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildLoadActionType(section), util_1.applySection(section, data));
    };
    /**
     * @stable [13.05.2019]
     * @param {string} section
     * @param {IDataWrapper<AnyT> & IPagedEntity} data
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildLoadDoneAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildLoadDoneActionType(section), util_1.applySection(section, data));
    };
    ListActionBuilder.buildNextPageAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildNextPageActionType(section), util_1.applySection(section, data));
    };
    ListActionBuilder.buildPreviousPageAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildPreviousPageActionType(section), util_1.applySection(section, data));
    };
    ListActionBuilder.buildFirstPageAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildFirstPageActionType(section), util_1.applySection(section, data));
    };
    ListActionBuilder.buildLastPageAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildLastPageActionType(section), util_1.applySection(section, data));
    };
    /**
     * @stable [20.10.2019]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildMergeActionType = function (section) {
        return section + "." + list_interface_1.LIST_MERGE_ACTION_TYPE;
    };
    /**
     * @stable [20.10.2019]
     * @param {string} section
     * @param {IModifyEntityPayloadWrapperEntity} data
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildMergeAction = function (section, data) {
        var plainAction = this.buildMergePlainAction(section, data);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [20.10.2019]
     * @param {string} section
     * @param {IModifyEntityPayloadWrapperEntity} data
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildMergePlainAction = function (section, data) {
        return {
            type: this.buildMergeActionType(section),
            data: util_1.applySection(section, data),
        };
    };
    /**
     * @stable [20.10.2019]
     * @param {string} section
     * @param {ISelectEntityPayloadEntity} payload
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildSelectAction = function (section, payload) {
        var plainAction = this.buildSelectPlainAction(section, payload);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [20.10.2019]
     * @param {string} section
     * @param {ISelectEntityPayloadEntity} payload
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildSelectPlainAction = function (section, payload) {
        return {
            type: this.buildSelectActionType(section),
            data: util_1.applySection(section, payload),
        };
    };
    /**
     * @stable [20.01.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildCreatePlainAction = function (section) {
        return {
            type: this.buildCreateActionType(section),
            data: util_1.applySection(section),
        };
    };
    return ListActionBuilder;
}());
exports.ListActionBuilder = ListActionBuilder;
//# sourceMappingURL=list-action.builder.js.map