"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../../util");
var link_1 = require("../../link");
var list_1 = require("../../list");
var flex_1 = require("../../layout/flex");
var definition_1 = require("../../../definition");
var universal_component_1 = require("../../base/universal.component");
var NavigationList = /** @class */ (function (_super) {
    __extends(NavigationList, _super);
    function NavigationList() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @stable [24.10.2019]
     * @returns {JSX.Element}
     */
    NavigationList.prototype.render = function () {
        return (React.createElement("nav", { ref: this.selfRef, className: 'rac-navigation-list rac-no-user-select', onScroll: this.onScroll },
            React.createElement(list_1.ListDivider, null),
            this.props.items.map(this.toElement, this)));
    };
    /**
     * @stable [24.10.2019]
     */
    NavigationList.prototype.onScroll = function () {
        // Each plugin should override this method
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationItemEntity} item
     * @returns {JSX.Element}
     */
    NavigationList.prototype.toElement = function (item) {
        var _this = this;
        var isExpanded = this.isItemExpanded(item);
        var fullLayoutModeEnabled = this.fullLayoutModeEnabled;
        var label = this.t(item.label);
        switch (item.type) {
            case definition_1.NavigationItemTypesEnum.SUB_HEADER:
                var isGroupItemActive = !isExpanded && this.hasActiveChild(item);
                return (React.createElement(flex_1.FlexLayout, { key: this.toUniqueKey(item.label, 'label'), row: true, alignItemsCenter: true, className: util_1.toClassName('rac-navigation-list-group', isGroupItemActive
                        ? 'rac-navigation-list-item-active'
                        : (isExpanded ? 'rac-navigation-list-item-expanded' : '')), title: label, onClick: function () { return _this.onGroupLinkClick(item); } },
                    this.uiFactory.makeIcon({
                        key: this.toUniqueKey(item.label, 'group-icon'),
                        type: item.icon || 'list',
                        className: 'rac-navigation-list-icon',
                    }),
                    util_1.orNull(fullLayoutModeEnabled, function () { return React.createElement("span", { className: 'rac-navigation-list-group-label rac-flex-full' }, label); }),
                    util_1.orNull(fullLayoutModeEnabled, function () { return (_this.uiFactory.makeIcon({
                        key: _this.toUniqueKey(item.label, 'group-expand-icon'),
                        type: isExpanded ? 'dropdown-opened' : 'dropdown',
                        className: 'rac-navigation-list-group-expand-icon rac-navigation-list-icon',
                    })); })));
            case definition_1.NavigationItemTypesEnum.DIVIDER:
                return util_1.ifNotFalseThanValue(this.props.dividerRendered, function () { return React.createElement(list_1.ListDivider, { key: R.isNil(item.parent) ? util_1.uuid() : _this.toUniqueKey(item.parent.label, 'divider') }); });
            default:
                var itemAsGroup_1 = R.isNil(item.parent);
                return util_1.orNull(isExpanded || itemAsGroup_1, function () { return (React.createElement(link_1.Link, { to: item.link, key: _this.toUniqueKey(item.link, 'link'), className: util_1.toClassName('rac-navigation-list-item', item.active
                        ? 'rac-navigation-list-item-active'
                        : (isExpanded ? 'rac-navigation-list-item-expanded' : ''), itemAsGroup_1 && 'rac-navigation-list-item-as-group', 'rac-flex', 'rac-flex-row', 'rac-flex-full', 'rac-flex-align-items-center'), title: label },
                    _this.uiFactory.makeIcon({
                        type: item.icon,
                        key: _this.toUniqueKey(item.link, 'icon'),
                        className: 'rac-navigation-list-icon',
                    }),
                    util_1.orNull(fullLayoutModeEnabled, function () { return React.createElement("span", { className: 'rac-navigation-list-item-label' }, label); }))); });
        }
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationItemEntity} config
     */
    NavigationList.prototype.onGroupLinkClick = function (config) {
        var props = this.props;
        if (props.onGroupClick) {
            props.onGroupClick(config);
        }
    };
    /**
     * @stable [23.09.2018]
     * @param {string} link
     * @param {string} prefix
     * @returns {string}
     */
    NavigationList.prototype.toUniqueKey = function (link, prefix) {
        return "navigation-list-key-" + link + "-" + prefix;
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationItemEntity} item
     * @returns {boolean}
     */
    NavigationList.prototype.isItemExpanded = function (item) {
        var expandedGroups = this.props.expandedGroups;
        return expandedGroups[item.value] === true
            || (!R.isNil(item.parent) && expandedGroups[item.parent.value] === true);
    };
    Object.defineProperty(NavigationList.prototype, "fullLayoutModeEnabled", {
        /**
         * @stable [23.09.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.props.mode === definition_1.LayoutModeEnum.FULL;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [23.09.2018]
     * @param {INavigationItemEntity} item
     * @returns {boolean}
     */
    NavigationList.prototype.hasActiveChild = function (item) {
        var activeItem = R.find(function (itm) { return !!itm.active; }, this.props.items);
        return !R.isNil(activeItem) && !R.isNil(R.find(function (child) { return child.link === activeItem.link; }, item.children || []));
    };
    return NavigationList;
}(universal_component_1.UniversalComponent));
exports.NavigationList = NavigationList;
//# sourceMappingURL=navigation-list.component.js.map