"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var definitions_interface_1 = require("../../definitions.interface");
var util_1 = require("../../util");
var base_component_1 = require("../base/base.component");
var dialog_1 = require("../dialog");
var definition_1 = require("../../definition");
var field_1 = require("../field");
var list_1 = require("../list");
var Menu = /** @class */ (function (_super) {
    __extends(Menu, _super);
    /**
     * @stable [31.07.2018]
     * @param {IMenuProps} props
     */
    function Menu(props) {
        var _this = _super.call(this, props) || this;
        _this.dialogRef = React.createRef();
        _this.fieldRef = React.createRef();
        _this.menuAnchorRef = React.createRef();
        /**
         * @stable [17.06.2019]
         * @param {IMenuItemEntity} itm
         * @returns {StringNumberT}
         */
        _this.optionValueFn = function (itm) { return (itm.label ? _this.t(itm.label) : itm.value); };
        _this.getItemElement = _this.getItemElement.bind(_this);
        _this.hide = _this.hide.bind(_this);
        _this.onDialogDeactivate = _this.onDialogDeactivate.bind(_this);
        _this.onFilterValueChange = _this.onFilterValueChange.bind(_this);
        _this.onSelect = _this.onSelect.bind(_this);
        _this.state = { opened: false };
        _this.filterQueryTask = new util_1.DelayedTask(_this.onFilterValueDelayedChange.bind(_this), 500);
        return _this;
    }
    /**
     * @stable [18.06.2019]
     * @returns {JSX.Element}
     */
    Menu.prototype.render = function () {
        var props = this.props;
        var filterElement = this.filterElement;
        if (this.centeredMenu) {
            return (this.state.opened && (React.createElement(dialog_1.Dialog, { ref: this.dialogRef, className: 'rac-menu-dialog', closable: false, acceptable: false, onDeactivate: this.onDialogDeactivate },
                this.closeActionElement,
                filterElement,
                this.listElement)));
        }
        return (React.createElement("div", { ref: this.menuAnchorRef, className: this.uiFactory.menuAnchor },
            React.createElement("div", { ref: this.selfRef, style: __assign({}, !this.centeredMenu && { width: util_1.calc(props.width) }), className: util_1.joinClassName('rac-menu', props.className, this.uiFactory.menu, this.uiFactory.menuSurface) },
                filterElement,
                this.listElement)));
    };
    /**
     * @stable [18.06.2019]
     */
    Menu.prototype.componentWillUnmount = function () {
        this.unsubscribeAllCaptureEvents();
        this.filterQueryTask.stop();
        _super.prototype.componentWillUnmount.call(this);
    };
    Object.defineProperty(Menu.prototype, "centeredMenu", {
        /**
         * @stable [17.06.2019]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isCenteredMenu(this.props);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [04.10.2018]
     */
    Menu.prototype.show = function () {
        var _this = this;
        var props = this.props;
        this.setState({ filter: definitions_interface_1.UNDEF, opened: true }, function () {
            if (_this.doesDialogExist) {
                _this.dialog.activate();
            }
            if (_this.isFilterUsed) {
                _this.field.setFocus();
            }
            if (!_this.centeredMenu) {
                _this.unsubscribeAllCaptureEvents();
                _this.syntheticScrollEventUnsubscriber = _this.domAccessor.captureEventWithinElement({
                    autoUnsubscribe: true,
                    callback: _this.hide,
                    element: _this.selfRef.current,
                    eventName: definition_1.SyntheticEventsEnum.SCROLL,
                });
                _this.resizeUnsubscriber = _this.domAccessor.captureEvent({
                    autoUnsubscribe: true,
                    callback: _this.hide,
                    eventName: definition_1.EventsEnum.RESIZE,
                });
            }
        });
        util_1.ifNotNilThanValue(util_1.nvl(props.xPosition, props.yPosition), function () {
            var el = _this.menuAnchorRef.current;
            _this.domAccessor.addClassNames(el, 'rac-absolute');
            _this.domAccessor.applyPosition(el, 'left', props.xPosition);
            _this.domAccessor.applyPosition(el, 'top', props.yPosition);
        });
    };
    /**
     * @stable [18.06.2019]
     */
    Menu.prototype.hide = function () {
        var props = this.props;
        this.setState({ opened: false }, function () {
            if (util_1.isFn(props.onClose)) {
                props.onClose();
            }
        });
    };
    /**
     * @stable [29.11.2018]
     * @returns {boolean}
     */
    Menu.prototype.isOpen = function () {
        return this.state.opened;
    };
    Object.defineProperty(Menu.prototype, "items", {
        /**
         * @stable [23.11.2019]
         * @returns {IMenuItemEntity[]}
         */
        get: function () {
            var _this = this;
            var props = this.props;
            return !this.isFilterUsed || util_1.isRemoteFilter(props)
                ? props.options
                : props.options.filter(function (option) { return props.filter(_this.state.filter, option); });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [23.11.2019]
     * @param {string} filter
     */
    Menu.prototype.onFilterValueChange = function (filter) {
        this.setState({ filter: filter });
        this.filterQueryTask.start();
    };
    /**
     * @stable [23.11.2019]
     */
    Menu.prototype.onFilterValueDelayedChange = function () {
        var props = this.props;
        if (util_1.isFn(props.onFilterChange)) {
            props.onFilterChange(this.state.filter);
        }
    };
    /**
     * @stable [23.11.2019]
     * @param {IMenuItemEntity} option
     */
    Menu.prototype.onSelect = function (option) {
        var props = this.props;
        if (util_1.isFn(props.onSelect)) {
            props.onSelect(option);
        }
        if (util_1.isMulti(props) && this.items.length > 1) {
            // Because a "Flux Cycle", to prevent empty list after updating
            return;
        }
        this.hide();
    };
    /**
     * @stable [17.06.2019]
     */
    Menu.prototype.onDialogDeactivate = function () {
        this.setState({ opened: false });
    };
    /**
     * @stable [23.11.2019]
     */
    Menu.prototype.unsubscribeAllCaptureEvents = function () {
        if (util_1.isFn(this.syntheticScrollEventUnsubscriber)) {
            this.syntheticScrollEventUnsubscriber();
            this.syntheticScrollEventUnsubscriber = null;
        }
        if (util_1.isFn(this.resizeUnsubscriber)) {
            this.resizeUnsubscriber();
            this.resizeUnsubscriber = null;
        }
    };
    Object.defineProperty(Menu.prototype, "listElement", {
        /**
         * @stable [23.09.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement(list_1.SimpleList, { className: this.uiFactory.list }, util_1.subArray(this.items, this.props.maxCount).map(this.getItemElement)));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [23.09.2019]
     * @param {IMenuItemEntity} option
     * @returns {JSX.Element}
     */
    Menu.prototype.getItemElement = function (option) {
        var props = this.props;
        return (React.createElement(list_1.ListItem, { key: "menu-item-key-" + option.value, disabled: option.disabled, icon: option.icon, rawData: option, renderer: props.renderer, tpl: props.tpl, onClick: this.onSelect }, this.optionValueFn(option)));
    };
    Object.defineProperty(Menu.prototype, "filterElement", {
        /**
         * @stable [17.06.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            var props = this.props;
            var state = this.state;
            return (React.createElement(field_1.TextField, { ref: this.fieldRef, full: false, value: state.filter, visible: this.isFilterUsed, placeholder: props.filterPlaceholder || this.settings.messages.FILTER_PLACEHOLDER, errorMessageRendered: false, onChange: this.onFilterValueChange }));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "closeActionElement", {
        /**
         * @stable [06.07.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            return (this.uiFactory.makeIcon({
                key: 'menu-close-action-key',
                type: 'close',
                className: 'rac-menu-dialog-icon-close',
                onClick: this.hide,
            }));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "isFilterUsed", {
        /**
         * @stable [23.11.2019]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isFilterUsed(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "doesDialogExist", {
        /**
         * @stable [17.05.2019]
         * @returns {boolean}
         */
        get: function () {
            return !R.isNil(this.dialog);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "field", {
        /**
         * @stable [07.06.2018]
         * @returns {IField}
         */
        get: function () {
            return this.fieldRef.current;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "dialog", {
        /**
         * @stable [17.06.2019]
         * @returns {Dialog<AnyT>}
         */
        get: function () {
            return this.dialogRef.current;
        },
        enumerable: true,
        configurable: true
    });
    Menu.defaultProps = {
        filter: function (query, entity) { return util_1.queryFilter(query, entity.label || entity.value); },
    };
    return Menu;
}(base_component_1.BaseComponent));
exports.Menu = Menu;
//# sourceMappingURL=menu.component.js.map