"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../util");
var base_1 = require("../base");
var flex_1 = require("../layout/flex");
var TabPanel = /** @class */ (function (_super) {
    __extends(TabPanel, _super);
    /**
     * @stable [11.08.2018]
     * @param {ITabPanelProps} props
     */
    function TabPanel(props) {
        var _this = _super.call(this, props) || this;
        _this.getTabElement = _this.getTabElement.bind(_this);
        _this.state = {};
        return _this;
    }
    /**
     * @stable [02.09.2018]
     */
    TabPanel.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        this.onDeactivateValue();
    };
    /**
     * @stable [04.10.2018]
     * @returns {JSX.Element}
     */
    TabPanel.prototype.render = function () {
        var _this = this;
        var props = this.props;
        var items = props.items;
        if (items.length <= 1) {
            return null;
        }
        return (React.createElement(flex_1.FlexLayout, { full: false, noShrink: true, className: 'rac-tab-panel-wrapper rac-no-user-select' },
            React.createElement("div", { ref: 'self', className: util_1.toClassName('rac-tab-panel', 'rac-flex', 'rac-flex-row', props.centered && 'rac-flex-center', props.className, this.uiFactory.tabBar) },
                util_1.orNull(props.backwardRendered, function () { return (_this.uiFactory.makeIcon({
                    type: 'navigate_before',
                    className: 'rac-tab-nav-icon',
                    onClick: _this.onBackward,
                })); }),
                React.createElement("div", { className: util_1.toClassName(this.uiFactory.tabBarScroller, 'rac-tab-scroller') },
                    React.createElement("div", { className: util_1.toClassName(this.uiFactory.tabBarScrollerScrollArea, this.uiFactory.tabBarScrollerScrollAreaScroll) },
                        React.createElement("div", { className: util_1.toClassName('rac-tab-scroll-content', 'rac-flex-center', this.uiFactory.tabBarScrollerScrollContent) }, items.map(this.getTabElement)))),
                util_1.orNull(props.forwardRendered, function () { return (_this.uiFactory.makeIcon({
                    type: 'navigate_next',
                    className: 'rac-tab-nav-icon',
                    onClick: _this.onForward,
                })); }))));
    };
    /**
     * Each plugin may implement this method
     * @stable [15.08.2018]
     */
    TabPanel.prototype.onForward = function () {
        // Do nothing
    };
    /**
     * Each plugin may implement this method
     * @stable [15.08.2018]
     */
    TabPanel.prototype.onBackward = function () {
        // Do nothing
    };
    /**
     * @stable [14.08.2018]
     * @param {ITabConfiguration} tab
     */
    TabPanel.prototype.onTabClick = function (tab) {
        var props = this.props;
        this.setState({ activeValue: tab.value });
        this.onDeactivateValue();
        if (util_1.isFn(props.onClick)) {
            props.onClick(tab);
        }
    };
    /**
     * @stable [02.09.2018]
     */
    TabPanel.prototype.onDeactivateValue = function () {
        var props = this.props;
        if (util_1.isFn(props.onDeactivate)) {
            props.onDeactivate(this.activeValue);
        }
    };
    /**
     * @stable [04.10.2018]
     * @param {ITabConfiguration} tab
     * @param {number} index
     * @returns {JSX.Element}
     */
    TabPanel.prototype.getTabElement = function (tab, index) {
        var _this = this;
        var props = this.props;
        var items = props.items;
        var activeValue = this.activeValue;
        var isTabActivate = tab.value === activeValue;
        var isLastTabActive = index === items.length - 1;
        var isFirstTabActive = index === 0;
        return (React.createElement("div", { key: "rac-tab-key-" + tab.value, className: util_1.toClassName('rac-tab', tab.selected && 'rac-tab-selected', items[index + 1] && items[index + 1].value === activeValue && 'rac-previous-tab-active', !isTabActivate && index % 2 === 0 && 'rac-tab-odd', !isTabActivate && isFirstTabActive && 'rac-first-tab', !isTabActivate && isLastTabActive && 'rac-last-tab', isFirstTabActive && 'rac-simple-first-tab', isLastTabActive && 'rac-simple-last-tab', util_1.orNull(isTabActivate, 'rac-tab-active')), onClick: function () { return _this.onTabClick(tab); } },
            React.createElement(flex_1.FlexLayout, { justifyContentCenter: true, alignItemsCenter: true, className: 'rac-tab-content' },
                React.createElement("div", null,
                    util_1.orNull(tab.url, function () { return (React.createElement("div", { className: 'rac-tab-url-icon-wrapper' },
                        React.createElement("img", { className: util_1.toClassName('rac-tab-url-icon', _this.uiFactory.tabIcon), src: tab.url }))); }),
                    util_1.orNull(tab.icon, function () { return _this.uiFactory.makeIcon({ type: tab.icon, className: _this.uiFactory.tabIcon }); }),
                    util_1.orNull(tab.url || tab.icon, function () { return (React.createElement("div", { className: util_1.toClassName('rac-tab-icon-text', _this.uiFactory.tabIconText) }, _this.t(tab.name))); }),
                    util_1.orNull(!(tab.url || tab.icon), function () { return _this.t(tab.name); }))),
            React.createElement("span", { className: util_1.toClassName(this.uiFactory.tabIndicator, !props.useIndicator && 'rac-display-none', util_1.orNull(tab.value === activeValue, this.uiFactory.tabIndicatorActive)) },
                React.createElement("span", { className: util_1.toClassName('rac-tab-indicator', this.uiFactory.tabIndicatorContent, this.uiFactory.tabIndicatorContentUnderline) }))));
    };
    Object.defineProperty(TabPanel.prototype, "activeValue", {
        /**
         * @stable [02.09.2018]
         * @returns {number}
         */
        get: function () {
            var props = this.props;
            var state = this.state;
            var items = props.items;
            return R.isNil(props.activeValue)
                ? (R.isNil(state.activeValue) ? (util_1.orNull(items.length, function () { return items[0].value; })) : state.activeValue)
                : props.activeValue;
        },
        enumerable: true,
        configurable: true
    });
    TabPanel.defaultProps = {
        useIndicator: true,
        rippable: true,
        forwardRendered: true,
        backwardRendered: true,
        centered: true,
    };
    return TabPanel;
}(base_1.BaseComponent));
exports.TabPanel = TabPanel;
//# sourceMappingURL=tabpanel.component.js.map