"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var redux_effects_promise_1 = require("redux-effects-promise");
var action_builder_1 = require("../../component/action.builder");
var chained_middleware_1 = require("./chained.middleware");
var util_1 = require("../../util");
/**
 * @stable [20.10.2019]
 * @param {IEditedListMiddlewareConfigEntity<TEntity extends IEntity, TState>} config
 * @returns {IChainedMiddlewareConfigEntity<TState, TEntity extends IEntity>}
 */
var toChainedConfigEntity = function (config) {
    return ({
        action: config.action,
        nextSection: config.formSection,
        path: config.path,
        payload: null,
        state: config.state,
    });
};
/**
 * @stable [20.10.2019]
 * @param {IEditedListMiddlewareConfigEntity<TEntity extends IEntity, TState>} config
 * @returns {IEffectsAction[]}
 */
exports.makeCreateEntityMiddleware = function (config) {
    return chained_middleware_1.makeChainedMiddleware(toChainedConfigEntity(config));
};
/**
 * @stable [19.10.2019]
 * @param {IEditedListMiddlewareConfigEntity<TEntity extends IEntity, TState>} config
 * @returns {IEffectsAction[]}
 */
exports.makeSelectEntityMiddleware = function (config) {
    var action = config.action;
    var selected = util_1.selectSelectedEntityFromAction(action);
    return config.lazyLoading
        ? [
            action_builder_1.ListActionBuilder.buildLazyLoadAction(config.listSection, util_1.defValuesFilter({
                selected: selected,
                preventEffects: util_1.selectPreventEffectsFromAction(action),
                previousAction: util_1.selectPreviousActionFromAction(action),
            }))
        ]
        : chained_middleware_1.makeChainedMiddleware({
            action: action,
            nextSection: config.formSection,
            path: config.path,
            payload: selected,
            state: config.state,
        });
};
/**
 * @stable [20.10.2019]
 * @param {IEditedListMiddlewareConfigEntity<TEntity extends IEntity, TState>} config
 * @returns {IEffectsAction[]}
 */
exports.makeLazyLoadedEntityMiddleware = function (config) {
    var action = config.action;
    var result = util_1.ifNotNilThanValue(util_1.selectPreviousActionTypeFromAction(action), function (previousActionType) { return [redux_effects_promise_1.EffectsAction.create(redux_effects_promise_1.EffectsActionBuilder.buildDoneActionType(previousActionType))]; }, []).concat(util_1.ifNotNilThanValue(chained_middleware_1.makeChainedMiddleware(__assign({}, toChainedConfigEntity(config), util_1.defValuesFilter({
        payload: action.data,
    }))), function (actions) { return actions; }, []));
    return util_1.orNull(util_1.isObjectNotEmpty(result), result);
};
//# sourceMappingURL=edited-list.middleware.js.map