"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var stack_interface_1 = require("./stack.interface");
var definition_1 = require("../../definition");
var stack_support_1 = require("./stack.support");
/**
 * @stable [20.09.2019]
 * @param {IStackEntity} state
 * @param {AnyAction} action
 * @returns {IStackEntity}
 */
exports.stackReducer = function (state, action) {
    if (state === void 0) { state = definition_1.INITIAL_STACK_ENTITY; }
    var stack = state.stack;
    var nextSection = action.data;
    var previousSection = action.data;
    var sectionsToDestroy = action.data;
    switch (action.type) {
        /**
         * @stable [21.09.2019]
         */
        case stack_interface_1.STACK_REMOVE_ACTION_TYPE:
            return __assign({}, state, { stack: R.filter(function (entry) { return !sectionsToDestroy.includes(entry.section); }, stack)
                    .map(function (itm) {
                    return (__assign({}, itm, { linkedSections: itm.linkedSections.filter(function (linkedSection) { return !sectionsToDestroy.includes(linkedSection); }) }));
                }) });
        /**
         * @stable [20.09.2019]
         * Is called from componentDidMount
         */
        case stack_interface_1.STACK_PUSH_ACTION_TYPE:
            return __assign({}, state, { destroySections: definition_1.INITIAL_STACK_ENTITY.destroySections }, (stack_support_1.findStackEntityIndex(nextSection, state) > -1 // If already inserted
                ? {}
                : {
                    stack: stack.concat([
                        { section: nextSection, linkedSections: [] }
                    ]),
                }));
        /**
         * @stable [20.09.2019]
         * Is called from componentWillUnmount
         */
        case stack_interface_1.STACK_POP_ACTION_TYPE:
            var additionalSectionsToDestroy_1 = stack_support_1.getAdditionalStackSectionsToDestroy(previousSection, state);
            return __assign({}, state, { lock: definition_1.INITIAL_STACK_ENTITY.lock, destroySections: definition_1.INITIAL_STACK_ENTITY.destroySections }, (state.lock
                ? {} // If there is a lock - do nothing
                : {
                    stack: stack
                        .slice(0, stack_support_1.findStackEntityIndex(previousSection, state) + 1)
                        .map(function (itm) {
                        return (__assign({}, itm, { linkedSections: itm.linkedSections.filter(function (itm0) { return !additionalSectionsToDestroy_1.includes(itm0); }) }));
                    }),
                    destroySections: additionalSectionsToDestroy_1,
                }));
        /**
         * @stable [21.09.2019]
         */
        case stack_interface_1.STACK_LOCK_ACTION_TYPE:
            return __assign({}, state, { lock: true, 
                // If there is a lock - we should attach the next section to linked sections
                stack: stack.map(function (entry, index) { return (index === stack.length - 1
                    ? __assign({}, entry, { linkedSections: Array.from(new Set(entry.linkedSections.concat(nextSection)
                            .filter(function (section) { return section !== entry.section; }) // Prevent the recursive links
                        )) }) : entry); }) });
    }
    return state;
};
//# sourceMappingURL=stack.reducer.js.map