"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var cond_1 = require("./cond");
var type_1 = require("./type");
var validator_1 = require("./validator");
/**
 * @stable [30.01.2019]
 * @param {Record<string, ValidatorRuleEnum[]>} payloads
 * @param {IEditableEntity<TEntity extends IEntity>} editableEntity
 * @param {boolean} canSaveEmptyChanges
 * @returns {boolean}
 */
exports.canSubmitEditableEntity = function (payloads, editableEntity, canSaveEmptyChanges) {
    if (canSaveEmptyChanges === void 0) { canSaveEmptyChanges = false; }
    return !editableEntity.progress
        && validator_1.validate(payloads, editableEntity.changes).valid
        && (canSaveEmptyChanges || !R.isEmpty(editableEntity.changes));
};
/**
 * @stable [30.01.2019]
 * @param {IFormWrapperEntity<TEntity extends IEntity>} entity
 * @param {Record<string, ValidatorRuleEnum[]>} editRules
 * @param {Record<string, ValidatorRuleEnum[]>} createRules
 * @returns {boolean}
 */
exports.canSubmitEntityFormEntity = function (entity, editRules, createRules) {
    return exports.canSubmitEditableEntity(exports.doesExtendedEntityExist(entity) ? editRules : createRules || editRules, entity.form);
};
/**
 * @stable [19.10.2019]
 * @param {TEntity} entity
 * @returns {boolean}
 */
exports.isNewEntity = function (entity) {
    return R.isNil(entity) || R.isNil(entity.id);
};
/**
 * @stable [01.10.2019]
 * @param {IExtendedEntity<TEntity extends IEntity>} extendedEntity
 * @returns {boolean}
 */
exports.isNewExtendedEntity = function (extendedEntity) {
    return cond_1.ifNotNilThanValue(extendedEntity, function () { return extendedEntity.newEntity === true; }, false);
};
/**
 * @stable [01.10.2019]
 * @param {IExtendedEntity<TEntity extends IEntity>} extendedEntity
 * @returns {boolean}
 */
exports.doesExtendedEntityExist = function (extendedEntity) {
    return !exports.isNewExtendedEntity(extendedEntity);
};
/**
 * @stable [30.08.2019]
 * @param {TEntity} entity
 * @returns {string}
 */
exports.entityAsFileName = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return "" + entity.id + cond_1.ifNotNilThanValue(entity.name, function (name) { return "-" + name.replace(/ /g, '_'); }, ''); }, ''); };
/**
 * @stable [12.10.2019]
 * @param {MultiFieldEntityT | EntityIdT} value
 * @returns {boolean}
 */
exports.isNotMultiEntity = function (value) {
    return Array.isArray(value) || type_1.isPrimitive(value);
};
//# sourceMappingURL=entity.js.map