"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _a;
var R = require("ramda");
var type_1 = require("./type");
/**
 * @stable [28.01.2019]
 */
var ValidatorRuleEnum;
(function (ValidatorRuleEnum) {
    ValidatorRuleEnum[ValidatorRuleEnum["NOT_NULL_NUMBER"] = 0] = "NOT_NULL_NUMBER";
    ValidatorRuleEnum[ValidatorRuleEnum["OPTIONAL_NUMBER"] = 1] = "OPTIONAL_NUMBER";
    ValidatorRuleEnum[ValidatorRuleEnum["NOT_EMPTY_STRING"] = 2] = "NOT_EMPTY_STRING";
})(ValidatorRuleEnum = exports.ValidatorRuleEnum || (exports.ValidatorRuleEnum = {}));
/**
 * @stable [28.01.2019]
 * @param value
 * @returns {boolean}
 */
exports.notNullNumber = function (value) { return type_1.isNumber(value); };
/**
 * @stable [28.01.2019]
 * @param value
 * @returns {boolean}
 */
exports.notNullString = function (value) { return type_1.isString(value); };
/**
 * @stable [28.01.2019]
 * @param value
 * @returns {boolean}
 */
exports.optionalNumber = function (value) { return R.isNil(value) || exports.notNullNumber(value); };
/**
 * @stable [28.01.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.notEmptyString = function (value) { return exports.notNullString(value) && !R.isEmpty(value); };
/**
 * @stable [28.01.2019]
 */
exports.ValidationRules = (_a = {},
    _a[ValidatorRuleEnum.NOT_NULL_NUMBER] = exports.notNullNumber,
    _a[ValidatorRuleEnum.OPTIONAL_NUMBER] = exports.optionalNumber,
    _a[ValidatorRuleEnum.NOT_EMPTY_STRING] = exports.notEmptyString,
    _a);
/**
 * @stable [28.01.2019]
 * @param {Record<string, ValidatorRuleEnum[]>} payloads
 * @param {IKeyValue} checkedObject
 * @returns {IValidationResultEntity}
 */
exports.validate = function (payloads, checkedObject) {
    var data = {};
    var valid = true;
    R.forEachObjIndexed(function (rules, fieldName) {
        var res = {};
        rules.forEach(function (ruleId) { return valid = valid && (res[ruleId] = exports.ValidationRules[ruleId](checkedObject[fieldName])); });
        data[fieldName] = res;
    }, payloads);
    return { valid: valid, data: data };
};
//# sourceMappingURL=validator.js.map